#!/bin/bash

# Sets up the FightingICE engine for Eclipse

# Instructions:
# - Put FTG3.00.zip in the same directory as this file (and the templates)
# - Run setup_fighting_ice.sh


# ---- Check if necessary files are present - if not, give an error and abort

NECESSARY_FILES=( downloads/FTG3.00.zip )

for FILE in "${NECESSARY_FILES[@]}"
do
	if [ ! -e "${FILE}" ]
	then
		echo "Error: File ${FILE} is not present in this directory. Aborting."
		echo "Please, download the file from http://www.ice.ci.ritsumei.ac.jp/~ftgaic/index-2.html"
		exit 1
	fi
done



# ---- Check if Java version is 8 or above - if not, give an error and abort

JAVA_VERSION=`java -version 2>&1 | grep "java version" | awk '{print $3}' | tr -d \" | awk '{split($0, array, ".")} END{print array[2]}'`
if [[ ${JAVA_VERSION} -lt 8 ]]
then
	echo "Error: Java version is ${JAVA_VERSION}, but version 8 or above is necessary."
	exit 1
fi



# Extract engine files
FIGHTING_ICE_PATH=`pwd`/../FTG3
rm -rf "${FIGHTING_ICE_PATH}"
unzip -u downloads/FTG3.00.zip -d "${FIGHTING_ICE_PATH}/" > /dev/null
mv "${FIGHTING_ICE_PATH}/"FTG3.00/FightingICEver.3.00/* "${FIGHTING_ICE_PATH}/"
rm -rf "${FIGHTING_ICE_PATH}/"FTG3.00

# Create Eclipse files
cp support_files/fighting_ice/eclipse/.classpath "${FIGHTING_ICE_PATH}/"
cp support_files/fighting_ice/eclipse/.project "${FIGHTING_ICE_PATH}/"

# Create IntelliJ Idea files
cp support_files/fighting_ice/intellij_idea/FightingICE.iml "${FIGHTING_ICE_PATH}/"
cp -R support_files/fighting_ice/intellij_idea/.idea "${FIGHTING_ICE_PATH}/"

echo "Done."
