#!/bin/bash

# Creates the project structure to develop an AI for FightingICE in Java in Eclipse.
# Expects the name of the AI as first and only parameter.


# First argument is optional, the java binary file path
if [ "$#" -ge 1 ]
then
	AI_NAME="$1"
else
	echo "No name specified for the AI. Abort."
	exit 1
fi



AI_PATH=`pwd`/../${AI_NAME}
if [ -e "${AI_PATH}" ]
then
    echo "A directory with that name already exists. Please, remove it. I do not like to take that kind of responsibility ;)"
else

    mkdir "${AI_PATH}"

    # Extract AIToolKit
    mkdir "${AI_PATH}/lib/"
    unzip -j downloads/FTG3.00.zip FTG3.00/FightingICEver.3.00/AIToolKit.jar -d "${AI_PATH}/lib/" > /dev/null

    # Generate template file
    mkdir "${AI_PATH}/src/"
    cp support_files/ai/ai_template.java "${AI_PATH}/src/${AI_NAME}.java"

    # Create Eclipse files
    cp support_files/ai/eclipse/.classpath "${AI_PATH}/"
    cp support_files/ai/eclipse/.project "${AI_PATH}/"

    # Create IntelliJ Idea files
    cp support_files/ai/intellij_idea/AI_NAME.iml "${AI_PATH}/"
    cp -R support_files/ai/intellij_idea/.idea "${AI_PATH}/"

    # Rename stuff
    find "${AI_PATH}/" -type f -print0 | xargs -0 sed -i "s/AI_NAME/${AI_NAME}/g"
    mv "${AI_PATH}/AI_NAME.iml" "${AI_PATH}/${AI_NAME}.iml"

    echo "Done."
fi
